summaryrefslogtreecommitdiffstats
path: root/kdecore/kdcoppropertyproxy.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:46:43 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:46:43 +0000
commitffe8a83e053396df448e9413828527613ca3bd46 (patch)
treea73d4169e02df4a50f9a12cb165fcd0ab5bac7c6 /kdecore/kdcoppropertyproxy.h
parent682bf3bfdcbcbb1fca85e8a36ed03e062e0555d5 (diff)
downloadtdelibs-ffe8a83e053396df448e9413828527613ca3bd46.tar.gz
tdelibs-ffe8a83e053396df448e9413828527613ca3bd46.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1157647 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kdecore/kdcoppropertyproxy.h')
-rw-r--r--kdecore/kdcoppropertyproxy.h44
1 files changed, 22 insertions, 22 deletions
diff --git a/kdecore/kdcoppropertyproxy.h b/kdecore/kdcoppropertyproxy.h
index 97b5f6f73..9bc7736e3 100644
--- a/kdecore/kdcoppropertyproxy.h
+++ b/kdecore/kdcoppropertyproxy.h
@@ -19,21 +19,21 @@
#ifndef __kdcoppropertyproxy_h__
#define __kdcoppropertyproxy_h__
-#include <qobject.h>
-#include <qcstring.h>
-#include <qvaluelist.h>
+#include <tqobject.h>
+#include <tqcstring.h>
+#include <tqvaluelist.h>
#include "kdelibs_export.h"
class KDCOPPropertyProxyPrivate;
/**
* The KDCOPPropertyProxy class provides an easy way to publish Qt properties of a
* QObject through DCOP.
*
* The class provides DCOP equivalents for the Qt property methods setProperty() ,
* property() and propertyNames() and also provides automatic set/get methods for
* the properties of a QObject. That means for example if your object provides a
* QString property called foo , then KDCOPPropertyProxy translates DCOP calls
* "setFoo( QString )" and "QString foo()" automatically into the corresponding
* setProperty/property calls.
*/
class KDECORE_EXPORT KDCOPPropertyProxy
@@ -41,10 +41,10 @@ class KDECORE_EXPORT KDCOPPropertyProxy
public:
/**
* Convenience constructor. Use it if you want to use this class as object, in contrary
* to using the static methods of this class and providing a QObject argument for each
* call.
*/
- KDCOPPropertyProxy( QObject *object );
+ KDCOPPropertyProxy( TQObject *object );
/**
* Destructor.
*/
@@ -54,31 +54,31 @@ public:
* Convenience method, when using this class as object. See documentation of the constructor and
* static isPropertyRequest method.
*/
- bool isPropertyRequest( const QCString &fun );
+ bool isPropertyRequest( const TQCString &fun );
/**
* Convenience method, when using this class as object. See documentation of the constructor and
* static processPropertyRequest method.
*/
- bool processPropertyRequest( const QCString &fun, const QByteArray &data, QCString &replyType,
- QByteArray &replyData );
+ bool processPropertyRequest( const TQCString &fun, const TQByteArray &data, TQCString &replyType,
+ TQByteArray &replyData );
/**
* Convenience method, when using this class as object. See documentation of the constructor and
* static functions method.
*/
- QValueList<QCString> functions();
+ TQValueList<TQCString> functions();
/**
* Returns a semicolon-separated list of functions understood by the PropertyProxy for the given
- * QObject argument.
+ * TQObject argument.
*
- * Returns "property(QCString);setProperty(QCString,QVariant);propertyNames();" plus set/get
+ * Returns "property(TQCString);setProperty(TQCString,TQVariant);propertyNames();" plus set/get
* methods for the properties of the given object argument.
*
* @see DCOPObject::functions()
*/
- static QValueList<QCString> functions( QObject *object );
+ static TQValueList<TQCString> functions( TQObject *object );
/**
* Returns true if the method request in the fun argument matches the signature of the three standard
@@ -87,18 +87,18 @@ public:
* Use this method in your own DCOPObject dispatcher to check if the DCOP request is a property
* request which can be handled by this class.
*/
- static bool isPropertyRequest( const QCString &fun, QObject *object );
+ static bool isPropertyRequest( const TQCString &fun, TQObject *object );
/**
* Processes the given DCOP method request by translating the request into a setProperty/property call
* on the given QObject argument.
*/
- static bool processPropertyRequest( const QCString &fun, const QByteArray &data, QCString &replyType,
- QByteArray &replyData, QObject *object );
+ static bool processPropertyRequest( const TQCString &fun, const TQByteArray &data, TQCString &replyType,
+ TQByteArray &replyData, TQObject *object );
private:
- static bool decodePropertyRequestInternal( const QCString &fun, QObject *object, bool &set,
- QCString &propName, QCString &arg );
+ static bool decodePropertyRequestInternal( const TQCString &fun, TQObject *object, bool &set,
+ TQCString &propName, TQCString &arg );
KDCOPPropertyProxyPrivate *d;
};
@@ -19,21 +19,21 @@
/**
* The KDCOPPropertyProxy class provides an easy way to publish Qt properties of a
- * QObject through DCOP.
+ * TQObject through DCOP.
*
* The class provides DCOP equivalents for the Qt property methods setProperty() ,
@@ -19,21 +19,21 @@
* The class provides DCOP equivalents for the Qt property methods setProperty() ,
* property() and propertyNames() and also provides automatic set/get methods for
- * the properties of a QObject. That means for example if your object provides a
- * QString property called foo , then KDCOPPropertyProxy translates DCOP calls
- * "setFoo( QString )" and "QString foo()" automatically into the corresponding
+ * the properties of a TQObject. That means for example if your object provides a
+ * TQString property called foo , then KDCOPPropertyProxy translates DCOP calls
+ * "setFoo( TQString )" and "TQString foo()" automatically into the corresponding
* setProperty/property calls.
*/
@@ -41,10 +41,10 @@ class KDECORE_EXPORT KDCOPPropertyProxy
/**
* Convenience constructor. Use it if you want to use this class as object, in contrary
- * to using the static methods of this class and providing a QObject argument for each
+ * to using the static methods of this class and providing a TQObject argument for each
* call.
*/
@@ -87,18 +87,18 @@ public:
/**
* Processes the given DCOP method request by translating the request into a setProperty/property call
- * on the given QObject argument.
+ * on the given TQObject argument.
*/